==> appmesh-2.13.6-sources.jar: software/amazon/awssdk/services/appmesh/paginators/ListMeshesIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.appmesh.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.appmesh.AppMeshClient;
import software.amazon.awssdk.services.appmesh.model.ListMeshesRequest;
import software.amazon.awssdk.services.appmesh.model.ListMeshesResponse;
import software.amazon.awssdk.services.appmesh.model.MeshRef;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.appmesh.AppMeshClient#listMeshesPaginator(software.amazon.awssdk.services.appmesh.model.ListMeshesRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.appmesh.model.ListMeshesResponse} that can be used to iterate through all the
 * response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.appmesh.paginators.ListMeshesIterable responses = client.listMeshesPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.appmesh.paginators.ListMeshesIterable responses = client.listMeshesPaginator(request);
 *     for (software.amazon.awssdk.services.appmesh.model.ListMeshesResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.appmesh.paginators.ListMeshesIterable responses = client.listMeshesPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listMeshes(software.amazon.awssdk.services.appmesh.model.ListMeshesRequest)} operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListMeshesIterable implements SdkIterable<ListMeshesResponse> {
    private final AppMeshClient client;

    private final ListMeshesRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListMeshesIterable(AppMeshClient client, ListMeshesRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListMeshesResponseFetcher();
    }

    @Override
    public Iterator<ListMeshesResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link ListMeshesResponse#meshes()} member. The returned
     * iterable is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<MeshRef> meshes() {
        Function<ListMeshesResponse, Iterator<MeshRef>> getIterator = response -> {
            if (response != null && response.meshes() != null) {
                return response.meshes().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<ListMeshesResponse, MeshRef> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class ListMeshesResponseFetcher implements SyncPageFetcher<ListMeshesResponse> {
        @Override
        public boolean hasNextPage(ListMeshesResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListMeshesResponse nextPage(ListMeshesResponse previousPage) {
            if (previousPage == null) {
                return client.listMeshes(firstRequest);
            }
            return client.listMeshes(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}

==> appmesh-2.19.19-sources.jar: software/amazon/awssdk/services/appmesh/paginators/ListMeshesIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.appmesh.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.appmesh.AppMeshClient;
import software.amazon.awssdk.services.appmesh.model.ListMeshesRequest;
import software.amazon.awssdk.services.appmesh.model.ListMeshesResponse;
import software.amazon.awssdk.services.appmesh.model.MeshRef;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.appmesh.AppMeshClient#listMeshesPaginator(software.amazon.awssdk.services.appmesh.model.ListMeshesRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.appmesh.model.ListMeshesResponse} that can be used to iterate through all the
 * response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.appmesh.paginators.ListMeshesIterable responses = client.listMeshesPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.appmesh.paginators.ListMeshesIterable responses = client.listMeshesPaginator(request);
 *     for (software.amazon.awssdk.services.appmesh.model.ListMeshesResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.appmesh.paginators.ListMeshesIterable responses = client.listMeshesPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Please notice that the configuration of limit won't limit the number of results you get with the paginator. It
 * only limits the number of results in each page.</b>
 * </p>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #listMeshes(software.amazon.awssdk.services.appmesh.model.ListMeshesRequest)} operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class ListMeshesIterable implements SdkIterable<ListMeshesResponse> {
    private final AppMeshClient client;

    private final ListMeshesRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public ListMeshesIterable(AppMeshClient client, ListMeshesRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new ListMeshesResponseFetcher();
    }

    @Override
    public Iterator<ListMeshesResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link ListMeshesResponse#meshes()} member. The returned
     * iterable is used to iterate through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<MeshRef> meshes() {
        Function<ListMeshesResponse, Iterator<MeshRef>> getIterator = response -> {
            if (response != null && response.meshes() != null) {
                return response.meshes().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<ListMeshesResponse, MeshRef> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class ListMeshesResponseFetcher implements SyncPageFetcher<ListMeshesResponse> {
        @Override
        public boolean hasNextPage(ListMeshesResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public ListMeshesResponse nextPage(ListMeshesResponse previousPage) {
            if (previousPage == null) {
                return client.listMeshes(firstRequest);
            }
            return client.listMeshes(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}
